import os

import altair as alt
import toolz

from camminapy.plot.altair_theme import (
    altair_theme_gray,
)


def altair_theme() -> None:
    for _ in range(2):
        alt.themes.register("theme_gray", altair_theme_gray)
        alt.themes.enable("theme_gray")


def altair_setup(csv_or_json: str = "json") -> None:
    alt.data_transformers.register("csv_dir", csv_dir)
    alt.data_transformers.register("json_dir", json_dir)
    for _ in range(2):  # For some reason I need to run this twice for it to work.
        alt.data_transformers.enable(
            f"{csv_or_json}_dir", data_dir="./.temporary_altair_data/"
        )


def csv_dir(data, data_dir="altairdata") -> None:
    return generic_dir(data, alt.to_csv, data_dir)


def json_dir(data, data_dir="altairdata") -> None:
    return generic_dir(data, alt.to_json, data_dir)


def generic_dir(data, to_disk: toolz.functoolz.curry, data_dir="altairdata") -> None:
    os.makedirs(data_dir, exist_ok=True)
    return toolz.curried.pipe(
        data, to_disk(filename=data_dir + "/{prefix} -{hash}.{extension}")
    )



import logging
from dataclasses import dataclass
from pathlib import Path


@dataclass
class Config:
    foldername_root: Path = Path(__file__).parent.parent.parent.resolve()
    foldername_log: Path = foldername_root / "logs"
    filename_debug_log: Path = foldername_log / "debug.log"

    logger_level: int = logging.DEBUG
    logger_shell_level: int = logging.DEBUG
    logger_file_level: int = logging.DEBUG

    logger_shell_fmt: str = "%(message)s"
    logger_file_fmt: str = (
        "%(levelname)s %(asctime)s [%(filename)s:%(funcName)s:%(lineno)d] \t%(message)s"
    )


config = Config()



import logging
import os

from rich.logging import RichHandler

from camminapy import config

logger = logging.getLogger(__name__)

shell_handler = RichHandler()
if not os.path.exists(config.foldername_log):
    os.makedirs(config.foldername_log)

file_handler = logging.FileHandler(config.filename_debug_log)

logger.setLevel(config.logger_level)
shell_handler.setLevel(config.logger_shell_level)
file_handler.setLevel(config.logger_file_level)


shell_formatter = logging.Formatter(config.logger_shell_fmt)
file_formatter = logging.Formatter(config.logger_file_fmt)

shell_handler.setFormatter(shell_formatter)
file_handler.setFormatter(file_formatter)

logger.addHandler(shell_handler)
logger.addHandler(file_handler)
